summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2015-06-05 00:18:00 +0100
committerCarl Hetherington <cth@carlh.net>2015-06-05 14:37:01 +0100
commit82787546680784a2a6e0993ab5b570f0db3a2d4d (patch)
tree621aaf7d25e539bc02448647aead0e0affd0932a /src
parentfe99eae4b95c5fcf2f3730efad4a18d0cb5c29bc (diff)
Rename ReelMXFAsset -> ReelEncryptableAsset.
Diffstat (limited to 'src')
-rw-r--r--src/decrypted_kdm.cc6
-rw-r--r--src/encrypted_kdm.cc2
-rw-r--r--src/reel_encryptable_asset.cc (renamed from src/reel_mxf_asset.cc)12
-rw-r--r--src/reel_encryptable_asset.h (renamed from src/reel_mxf_asset.h)28
-rw-r--r--src/reel_picture_asset.cc6
-rw-r--r--src/reel_picture_asset.h6
-rw-r--r--src/reel_sound_asset.cc4
-rw-r--r--src/reel_sound_asset.h6
-rw-r--r--src/wscript4
9 files changed, 40 insertions, 34 deletions
diff --git a/src/decrypted_kdm.cc b/src/decrypted_kdm.cc
index ddcacb34..68429a73 100644
--- a/src/decrypted_kdm.cc
+++ b/src/decrypted_kdm.cc
@@ -1,5 +1,5 @@
/*
- Copyright (C) 2013-2014 Carl Hetherington <cth@carlh.net>
+ Copyright (C) 2013-2015 Carl Hetherington <cth@carlh.net>
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
#include "decrypted_kdm.h"
#include "decrypted_kdm_key.h"
#include "encrypted_kdm.h"
-#include "reel_mxf_asset.h"
+#include "reel_encryptable_asset.h"
#include "util.h"
#include "exceptions.h"
#include "cpl.h"
@@ -200,7 +200,7 @@ DecryptedKDM::DecryptedKDM (
{
/* Create DecryptedKDMKey objects for each MXF asset */
BOOST_FOREACH(shared_ptr<const ReelAsset> i, cpl->reel_assets ()) {
- shared_ptr<const ReelMXFAsset> mxf = boost::dynamic_pointer_cast<const ReelMXFAsset> (i);
+ shared_ptr<const ReelEncryptableAsset> mxf = boost::dynamic_pointer_cast<const ReelEncryptableAsset> (i);
if (mxf) {
if (!mxf->key_id ()) {
throw NotEncryptedError (mxf->id());
diff --git a/src/encrypted_kdm.cc b/src/encrypted_kdm.cc
index 7cae0533..4d41a066 100644
--- a/src/encrypted_kdm.cc
+++ b/src/encrypted_kdm.cc
@@ -1,5 +1,5 @@
/*
- Copyright (C) 2013-2014 Carl Hetherington <cth@carlh.net>
+ Copyright (C) 2013-2015 Carl Hetherington <cth@carlh.net>
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
diff --git a/src/reel_mxf_asset.cc b/src/reel_encryptable_asset.cc
index f32ea805..957fab28 100644
--- a/src/reel_mxf_asset.cc
+++ b/src/reel_encryptable_asset.cc
@@ -17,7 +17,7 @@
*/
-#include "reel_mxf_asset.h"
+#include "reel_encryptable_asset.h"
#include "mxf.h"
#include "dcp_assert.h"
#include <libcxml/cxml.h>
@@ -28,20 +28,22 @@ using boost::shared_ptr;
using boost::optional;
using namespace dcp;
-ReelMXFAsset::ReelMXFAsset ()
+ReelEncryptableAsset::ReelEncryptableAsset ()
: ReelAsset ()
{
}
-ReelMXFAsset::ReelMXFAsset (shared_ptr<Asset> asset, optional<string> key_id, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point)
+ReelEncryptableAsset::ReelEncryptableAsset (
+ shared_ptr<Asset> asset, optional<string> key_id, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point
+ )
: ReelAsset (asset, edit_rate, intrinsic_duration, entry_point)
, _key_id (key_id)
{
}
-ReelMXFAsset::ReelMXFAsset (shared_ptr<const cxml::Node> node)
+ReelEncryptableAsset::ReelEncryptableAsset (shared_ptr<const cxml::Node> node)
: ReelAsset (node)
, _key_id (node->optional_string_child ("KeyId"))
{
@@ -51,7 +53,7 @@ ReelMXFAsset::ReelMXFAsset (shared_ptr<const cxml::Node> node)
}
void
-ReelMXFAsset::write_to_cpl (xmlpp::Node* node, Standard s) const
+ReelEncryptableAsset::write_to_cpl (xmlpp::Node* node, Standard s) const
{
ReelAsset::write_to_cpl (node, s);
diff --git a/src/reel_picture_asset.cc b/src/reel_picture_asset.cc
index fd18dc30..a989f72b 100644
--- a/src/reel_picture_asset.cc
+++ b/src/reel_picture_asset.cc
@@ -1,5 +1,5 @@
/*
- Copyright (C) 2014 Carl Hetherington <cth@carlh.net>
+ Copyright (C) 2014-2015 Carl Hetherington <cth@carlh.net>
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ ReelPictureAsset::ReelPictureAsset ()
}
ReelPictureAsset::ReelPictureAsset (shared_ptr<PictureAsset> asset, int64_t entry_point)
- : ReelMXFAsset (asset, asset->key_id(), asset->edit_rate(), asset->intrinsic_duration(), entry_point)
+ : ReelEncryptableAsset (asset, asset->key_id(), asset->edit_rate(), asset->intrinsic_duration(), entry_point)
, _frame_rate (asset->frame_rate ())
, _screen_aspect_ratio (asset->screen_aspect_ratio ())
{
@@ -52,7 +52,7 @@ ReelPictureAsset::ReelPictureAsset (shared_ptr<PictureAsset> asset, int64_t entr
}
ReelPictureAsset::ReelPictureAsset (shared_ptr<const cxml::Node> node)
- : ReelMXFAsset (node)
+ : ReelEncryptableAsset (node)
{
_frame_rate = Fraction (node->string_child ("FrameRate"));
try {
diff --git a/src/reel_picture_asset.h b/src/reel_picture_asset.h
index a41cd9d2..98615c72 100644
--- a/src/reel_picture_asset.h
+++ b/src/reel_picture_asset.h
@@ -1,5 +1,5 @@
/*
- Copyright (C) 2014 Carl Hetherington <cth@carlh.net>
+ Copyright (C) 2014-2015 Carl Hetherington <cth@carlh.net>
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
#ifndef LIBDCP_REEL_PICTURE_ASSET_H
#define LIBDCP_REEL_PICTURE_ASSET_H
-#include "reel_mxf_asset.h"
+#include "reel_encryptable_asset.h"
#include "picture_asset.h"
namespace dcp {
@@ -32,7 +32,7 @@ namespace dcp {
/** @class ReelPictureAsset
* @brief Part of a Reel's description which refers to a picture asset.
*/
-class ReelPictureAsset : public ReelMXFAsset
+class ReelPictureAsset : public ReelEncryptableAsset
{
public:
ReelPictureAsset ();
diff --git a/src/reel_sound_asset.cc b/src/reel_sound_asset.cc
index b3ca5234..131672b8 100644
--- a/src/reel_sound_asset.cc
+++ b/src/reel_sound_asset.cc
@@ -30,13 +30,13 @@ using boost::shared_ptr;
using namespace dcp;
ReelSoundAsset::ReelSoundAsset (shared_ptr<SoundAsset> asset, int64_t entry_point)
- : ReelMXFAsset (asset, asset->key_id(), asset->edit_rate(), asset->intrinsic_duration(), entry_point)
+ : ReelEncryptableAsset (asset, asset->key_id(), asset->edit_rate(), asset->intrinsic_duration(), entry_point)
{
}
ReelSoundAsset::ReelSoundAsset (shared_ptr<const cxml::Node> node)
- : ReelMXFAsset (node)
+ : ReelEncryptableAsset (node)
{
node->ignore_child ("Language");
node->done ();
diff --git a/src/reel_sound_asset.h b/src/reel_sound_asset.h
index d7eee59d..9902faa4 100644
--- a/src/reel_sound_asset.h
+++ b/src/reel_sound_asset.h
@@ -1,5 +1,5 @@
/*
- Copyright (C) 2014 Carl Hetherington <cth@carlh.net>
+ Copyright (C) 2014-2015 Carl Hetherington <cth@carlh.net>
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
* @brief ReelSoundAsset class.
*/
-#include "reel_mxf_asset.h"
+#include "reel_encryptable_asset.h"
#include "sound_asset.h"
#include <boost/shared_ptr.hpp>
#include <string>
@@ -31,7 +31,7 @@ namespace dcp {
/** @class ReelSoundAsset
* @brief Part of a Reel's description which refers to a sound MXF.
*/
-class ReelSoundAsset : public ReelMXFAsset
+class ReelSoundAsset : public ReelEncryptableAsset
{
public:
ReelSoundAsset (boost::shared_ptr<dcp::SoundAsset> content, int64_t entry_point);
diff --git a/src/wscript b/src/wscript
index ac3d9b0c..371f11c4 100644
--- a/src/wscript
+++ b/src/wscript
@@ -34,8 +34,8 @@ def build(bld):
picture_asset_writer.cc
reel.cc
reel_asset.cc
+ reel_encryptable_asset.cc
reel_mono_picture_asset.cc
- reel_mxf_asset.cc
reel_picture_asset.cc
reel_sound_asset.cc
reel_stereo_picture_asset.cc
@@ -95,8 +95,8 @@ def build(bld):
rgb_xyz.h
reel.h
reel_asset.h
+ reel_encryptable_asset.h
reel_mono_picture_asset.h
- reel_mxf_asset.h
reel_picture_asset.h
reel_sound_asset.h
reel_stereo_picture_asset.h
diff --git a/src/reel_mxf_asset.h b/src/reel_encryptable_asset.h
index 2dc3af73..b1c3eb16 100644
--- a/src/reel_mxf_asset.h
+++ b/src/reel_encryptable_asset.h
@@ -17,28 +17,32 @@
*/
-/** @file src/reel_mxf_asset.h
- * @brief ReelMXFAsset
+/** @file src/reel_encryptable_asset.h
+ * @brief ReelEncryptableAsset
*/
-#ifndef LIBDCP_REEL_MXF_ASSET_H
-#define LIBDCP_REEL_MXF_ASSET_H
+#ifndef LIBDCP_REEL_ENCRYPTABLE_ASSET_H
+#define LIBDCP_REEL_ENCRYPTABLE_ASSET_H
#include "reel_asset.h"
namespace dcp {
-class MXF;
-
-/** @class ReelMXFAsset
- * @brief Part of a Reel's description which refers to an MXF.
+/** @class ReelEncryptableAsset
+ * @brief Part of a Reel's description which refers to an asset which can be encrypted.
*/
-class ReelMXFAsset : public ReelAsset
+class ReelEncryptableAsset : public ReelAsset
{
public:
- ReelMXFAsset ();
- ReelMXFAsset (boost::shared_ptr<Asset> asset, boost::optional<std::string> key_id, Fraction edit_rate, int64_t intrinsic_duration, int64_t entry_point);
- ReelMXFAsset (boost::shared_ptr<const cxml::Node>);
+ ReelEncryptableAsset ();
+ ReelEncryptableAsset (
+ boost::shared_ptr<Asset> asset,
+ boost::optional<std::string> key_id,
+ Fraction edit_rate,
+ int64_t intrinsic_duration,
+ int64_t entry_point
+ );
+ ReelEncryptableAsset (boost::shared_ptr<const cxml::Node>);
/** @return the 4-character key type for this MXF (MDIK, MDAK, etc.) */
virtual std::string key_type () const = 0;